@@ -1,10 +1,10 @@
 #  Party System Indicators - Competitiveness----
 
 competitiveness <- function(votes) {
-     if (class(votes) != 'numeric') {
+     if (!is.numeric(votes)) {
           stop('Input vector must be numeric')
      }
-     if (length(votes) < 2 & class(votes) == 'numeric') {
+     if (length(votes) < 2 & is.numeric(votes)) {
           stop('Input vector must have minimal lenght of 2.')
      }
      fractions <- sort(votes/sum(votes), decreasing = TRUE)
